package org.acme.microprofile.metrics;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class ExampleResourceIT extends ExampleResourceTest {

}
